
Overview
========

ChaosMagPy is a simple Python package for evaluating the
`CHAOS-7 <http://www.spacecenter.dk/files/magnetic-models/CHAOS-7/>`_ geomagnetic
field model. To quickly get started, download a complete working example
including the latest model under the "Forward code" section.

| **Release:** v0.4
| **Version of CHAOS:** CHAOS-7.3 (0703)

Documentation
-------------

The documentation of the current release is available on
`Read the Docs <https://chaosmagpy.readthedocs.io/en/stable/>`_.

|pypi| |docs| |doi| |license|

.. |pypi| image:: https://badge.fury.io/py/chaosmagpy.svg
    :target: https://badge.fury.io/py/chaosmagpy

.. |docs| image:: https://readthedocs.org/projects/chaosmagpy/badge/?version=stable
   :target: https://chaosmagpy.readthedocs.io/en/stable/?badge=stable
   :alt: Documentation Status

.. |license| image:: https://img.shields.io/badge/License-MIT-blue.svg
   :target: license.html

.. |doi| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3352398.svg
   :target: https://doi.org/10.5281/zenodo.3352398
